@@ -6,14 +6,13 @@ import os
 import anydbm
 import urlparse
 import platform
-from urllib2 import urlopen
 from subprocess import *
 import json
 import time
 
+import gntplib
 import baker
 import feedparser
-from BeautifulSoup import BeautifulStoneSoup
 try:
     from urlgrabber.grabber import URLGrabber
 except ImportError:
@@ -93,19 +92,29 @@ def hitsquad():
 def growl(text):
     """send a growl notification if on mac osx (use GNTP or the growl lib)"""
     if platform.system() == 'Darwin':
-        #TODO: growl proper
-        if Popen(['which', 'growlnotify'], stdout=PIPE).communicate()[0]:
-            os.system("growlnotify -t Hitman -m %r" % str(text))
+        gntplib.publish("Hitman", "Status Update", "Hitman", text=text)
+        # if Popen(['which', 'growlnotify'], stdout=PIPE).communicate()[0]:
+        #     os.system("growlnotify -t Hitman -m %r" % str(text))
     elif platform.system() == 'Linux':
-        if Popen(['which', 'notify-send'], stdout=PIPE).communicate()[0]:
-            #Do an OSD-Notify
-            #notify-send "Totem" "This is a superfluous notification"
-            os.system("notify-send \"Hitman\" \"%r\" " % str(text))
+        try: 
+            import pynotify
+            pynotify.init("Hitman")
+            n = pynotify.Notification("Hitman Status Report", text)
+            n.set_timeout(pynotify.EXPIRES_DEFAULT)
+            n.show()
+        except ImportError:
+            if Popen(['which', 'notify-send'], stdout=PIPE).communicate()[0]:
+                #Do an OSD-Notify
+                #notify-send "Totem" "This is a superfluous notification"
+                os.system("notify-send \"Hitman\" \"%r\" " % str(text))
     elif platform.system() == 'Haiku':
         os.system("notify --type information --app Hitman \
         --title 'Status Report' '%s'" % str(text))
     elif platform.system() == 'Windows':
-        pass
+        try:
+            gntplib.publish("Hitman", "Status Update", "Hitman", text=text)
+        except:
+            print "Install Growl For windows if you want notifications! \n http://www.growlforwindows.com/gfw/"
     else:
         pass
         #Can I test for growl for windows?
@@ -118,7 +127,6 @@ def download(url, name, feed):
     db = anydbm.open(os.path.join(directory(), 'downloads'), 'c')
     g = URLGrabber(reget='simple')
     print "Downloading %s" % url
-    # try:
     settings = get_settings()
     if 'dl' in settings:
         save_name = os.path.join(settings['dl'], name)
@@ -142,7 +150,6 @@ def download(url, name, feed):
             else:
                 g.urlgrab(url)
                 os.chdir(old_pwd)
-        #db[url]= 'Downloaded'
         db[url.split('/')[-1]] = json.dumps({'url': url,
         'date': time.ctime(), 'feed': feed})
     except KeyboardInterrupt:
@@ -240,10 +247,6 @@ def list_feeds():
 def export_opml():
     "Export an OPML feed list"
     feeds = get_feeds()
-    # print feeds
-    #  for name in feeds:
-    #          print name
-    #          print feeds[name]
     #Thanks to the canto project- used under the GPL
     print """<opml version="1.0">"""
     print """<body>"""
@@ -265,15 +268,15 @@ def import_opml(url):
     """Import an OPML file locally or from a URL. Uses your text attributes as aliases."""
     #Test if URL given is local, then open, parse out feed urls,
     #add feeds, set text= to aliases and report success, list feeds added
+    from bs4 import BeautifulSoup
+    from urllib2 import urlopen
     try:
         f = file(url).read()
     except IOError:
         f = urlopen(url).read()
-    soup = BeautifulStoneSoup(f)
-    links = soup.findAll('outline', type="rss" or "pie")
+    soup = BeautifulSoup(f, "xml")
+    links = soup.find_all('outline', type="rss" or "pie")
     #This is very slow, might cache this info on add
-    #links.append(soup.findAll('outline', type="pie"))
-    #print links
     for link in links:
         #print link
         add_feed(link['xmlurl'])
